"use server";

import { revalidatePath } from "next/cache";
import { db } from "../db";
import { regions } from "../db/schema";
import { z } from "zod";

const schema = z.object({
  countryId: z.string().min(1, "No country selected"),
  name: z.string().min(1, "Name is required"),
});

export const addRegion = async (prevstate: any, formData: FormData) => {
  const newRegion = schema.safeParse({
    name: (formData.get("name") as string).toLowerCase(),
    countryId: formData.get("country") as string,
  });
  if (!newRegion.success) {
    return {
      message: "failed",
      errors: newRegion.error,
      data: null,
    };
  }
  const confirmedRegion = await db
    .insert(regions)
    .values(newRegion.data)
    .onConflictDoNothing()
    .returning({ name: regions.name });
  if (!confirmedRegion[0]?.name) {
    return {
      message: "region already exists",
      errors: newRegion.error,
      data: null,
    };
  } else {
    const message = `${newRegion.data.name} added`;
    const errors = newRegion.error;
    const data = newRegion.data;
    revalidatePath("/");
    return { message, errors, data };
  }
};
